texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[no subject]


From: Gavin D. Smith
Date: Wed, 30 Nov 2022 13:36:34 -0500 (EST)

branch: old/qt-info
commit 6e33bfbd8306e96d4ed4befeddbf08ee2ed8703d
Author: Gavin Smith <gavinsmith0123@gmail.com>
AuthorDate: Sun Apr 7 15:50:31 2019 +0100

    rename init function to wc_init
---
 ChangeLog  | 2 +-
 js/info.js | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 3bcd702f08..ad2959714c 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -4,7 +4,7 @@
 
        * js/Makefile.am: Build the examples with an empty htmlxref file 
        in order to produce relative links in the output.
-       * js/info.js (init): New function, to connect to a QWebChannel.
+       * js/info.js (wc_init): New function, to connect to a QWebChannel.
        (web_channel_override): New function, to override action 
        handling.
        (core): New object to represent communication channel with a 
diff --git a/js/info.js b/js/info.js
index 1806527a84..b00115c877 100644
--- a/js/info.js
+++ b/js/info.js
@@ -2038,7 +2038,7 @@ var core;
 
 // For use with QWebChannel.  init function to be called after
 // qwebchannel.js has been loaded.
-init = function ()
+wc_init = function ()
 {
   if (!inside_index_page)
     return;
@@ -2089,8 +2089,8 @@ init = function ()
 
 } (window["Modernizr"], window["INFO_CONFIG"]));
 
-// Make init function visible at external scope
-var init;
+// Make wc_init function visible at external scope
+var wc_init;
 
 // Return true if the standard function doesn't need to be called.
 // This is put in the external scope because we might want to inject



reply via email to

[Prev in Thread] Current Thread [Next in Thread]